The [AtomS3 Lite](https://shop.m5stack.com/products/atoms3-lite-esp32s3-dev-kit)
([docs](https://docs.m5stack.com/en/core/AtomS3%20Lite)) is an ESP32-S3 based
development board from [M5Stack](https://m5stack.com/).
